@@ -1,13 +1,13 @@
 import os
 
-os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = "hide"
 import numpy as np
 import pygame
 
+os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
+
 
 def manual_control(**kwargs):
     from .cooperative_pong import env as _env
-
     env = _env(**kwargs)
     env.reset()
 
