@@ -43,7 +43,7 @@ parallel_env = parallel_wrapper_fn(env)
 
 class raw_env(AECEnv, EzPickle):
 
-    metadata = {'render.modes': ['human', "rgb_array"], 'name': "pistonball_v4"}
+    metadata = {'render.modes': ['human', "rgb_array"], 'name': "pistonball_v5"}
 
     def __init__(self, n_pistons=20, time_penalty=-0.1, continuous=True, random_drop=True, random_rotate=True, ball_mass=0.75, ball_friction=0.3, ball_elasticity=1.5, max_cycles=125):
         EzPickle.__init__(self, n_pistons, time_penalty, continuous, random_drop, random_rotate, ball_mass, ball_friction, ball_elasticity, max_cycles)
@@ -411,6 +411,8 @@ class raw_env(AECEnv, EzPickle):
             ball_min_x = int(self.ball.position[0] - self.ball_radius)
             if ball_min_x <= self.wall_width + 1:
                 self.done = True
+            # ensures that the ball can't pass through the wall
+            ball_min_x = max(self.wall_width, ball_min_x)
             self.draw()
             local_reward = self.get_local_reward(self.lastX, ball_min_x)
             # Opposite order due to moving right to left
@@ -439,4 +441,4 @@ class raw_env(AECEnv, EzPickle):
         self._cumulative_rewards[agent] = 0
         self._accumulate_rewards()
 
-# Game art created by Justin Terry
+# Game art created by J K Terry
