@@ -1,11 +1,12 @@
 import os
 
-os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = "hide"
 import numpy as np
 import pygame
 
 from . import constants as const
 
+os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
+
 
 def manual_control(**kwargs):
     from .prospector import env as _env
@@ -20,9 +21,10 @@ def manual_control(**kwargs):
 
     while not done:
         clock.tick(const.FPS)
-        agent_actions = [np.array([0, 0, 0]) for _ in range(const.NUM_PROSPECTORS)] + [
-            np.array([0, 0]) for _ in range(const.NUM_BANKERS)
-        ]
+        agent_actions = (
+            [np.array([0, 0, 0]) for _ in range(const.NUM_PROSPECTORS)]
+            + [np.array([0, 0]) for _ in range(const.NUM_BANKERS)]
+        )
         for event in pygame.event.get():
             # Use left/right arrow keys to switch between agents
             # Use WASD to control bankers
