@@ -1,6 +1,3 @@
-import os
-
-os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = "hide"
 import itertools as it
 import math
 import os
@@ -21,6 +18,8 @@ from . import constants as const
 from . import utils
 from .manual_control import manual_control
 
+os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
+
 
 class CollisionTypes(IntEnum):
     PROSPECTOR = auto()
@@ -533,10 +532,7 @@ class raw_env(AECEnv, EzPickle):
             f = Fence(w_type, s_pos, b_pos, verts, self.space)
             self.fences.append(f)
 
-        self.metadata = {
-            "render.modes": ["human", "rgb_array"],
-            "name": "prospector_v4",
-        }
+        self.metadata = {"render.modes": ["human", "rgb_array"], 'name': "prospector_v4"}
 
         self.action_spaces = {}
         for p in self.prospectors:
@@ -564,12 +560,7 @@ class raw_env(AECEnv, EzPickle):
                 low=0, high=255, shape=const.BANKER_OBSERV_SHAPE, dtype=np.uint8
             )
 
-        self.state_space = spaces.Box(
-            low=0,
-            high=255,
-            shape=((const.SCREEN_HEIGHT, const.SCREEN_WIDTH, 3)),
-            dtype=np.uint8,
-        )
+        self.state_space = spaces.Box(low=0, high=255, shape=((const.SCREEN_HEIGHT, const.SCREEN_WIDTH, 3)), dtype=np.uint8)
 
         self.possible_agents = self.agents[:]
         self._agent_selector = agent_selector(self.agents)
@@ -714,9 +705,8 @@ class raw_env(AECEnv, EzPickle):
         x, y = ag.center  # Calculated property added to prospector and banker classes
         sub_screen = np.array(
             capture[
-                max(0, x - delta) : min(const.SCREEN_WIDTH, x + delta),
-                max(0, y - delta) : min(const.SCREEN_HEIGHT, y + delta),
-                :,
+                max(0, x - delta): min(const.SCREEN_WIDTH, x + delta),
+                max(0, y - delta): min(const.SCREEN_HEIGHT, y + delta), :,
             ],
             dtype=np.uint8,
         )
@@ -750,10 +740,16 @@ class raw_env(AECEnv, EzPickle):
 
         return sub_screen
 
+    def observation_space(self, agent):
+        return self.observation_spaces[agent]
+
+    def action_space(self, agent):
+        return self.action_spaces[agent]
+
     def state(self):
-        """
+        '''
         Returns an observation of the global environment
-        """
+        '''
         state = pg.surfarray.pixels3d(self.screen).copy()
         state = np.rot90(state, k=3)
         state = np.fliplr(state)
@@ -870,7 +866,7 @@ class raw_env(AECEnv, EzPickle):
             return transposed
 
     def full_draw(self):
-        """Called to draw everything when first rendering"""
+        """ Called to draw everything when first rendering """
         self.background.full_draw(self.screen)
         for f in self.fences:
             f.full_draw(self.screen)
@@ -878,7 +874,7 @@ class raw_env(AECEnv, EzPickle):
         self.all_sprites.draw(self.screen)
 
     def draw(self):
-        """Called after each frame, all agents updated"""
+        """ Called after each frame, all agents updated """
         self.background.draw(self.screen)
         for f in self.fences:
             f.full_draw(self.screen)
