@@ -45,8 +45,8 @@ GTP             'A19'           'T19'           'pass'
 from . import go
 
 # We provide more than 19 entries here in case of boards larger than 19 x 19.
-_SGF_COLUMNS = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
-_GTP_COLUMNS = "ABCDEFGHJKLMNOPQRSTUVWXYZ"
+_SGF_COLUMNS = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'
+_GTP_COLUMNS = 'ABCDEFGHJKLMNOPQRSTUVWXYZ'
 
 
 def from_flat(flat):
@@ -65,7 +65,7 @@ def to_flat(coord):
 
 def from_sgf(sgfc):
     """Converts from an SGF coordinate to a Minigo coordinate."""
-    if sgfc is None or sgfc == "" or (go.N <= 19 and sgfc == "tt"):
+    if sgfc is None or sgfc == '' or (go.N <= 19 and sgfc == 'tt'):
         return None
     return _SGF_COLUMNS.index(sgfc[1]), _SGF_COLUMNS.index(sgfc[0])
 
@@ -73,14 +73,14 @@ def from_sgf(sgfc):
 def to_sgf(coord):
     """Converts from a Minigo coordinate to an SGF coordinate."""
     if coord is None:
-        return ""
+        return ''
     return _SGF_COLUMNS[coord[1]] + _SGF_COLUMNS[coord[0]]
 
 
 def from_gtp(gtpc):
     """Converts from a GTP coordinate to a Minigo coordinate."""
     gtpc = gtpc.upper()
-    if gtpc == "PASS":
+    if gtpc == 'PASS':
         return None
     col = _GTP_COLUMNS.index(gtpc[0])
     row_from_bottom = int(gtpc[1:])
@@ -90,6 +90,6 @@ def from_gtp(gtpc):
 def to_gtp(coord):
     """Converts from a Minigo coordinate to a GTP coordinate."""
     if coord is None:
-        return "pass"
+        return 'pass'
     y, x = coord
-    return f"{_GTP_COLUMNS[x]}{go.N - y}"
+    return f'{_GTP_COLUMNS[x]}{go.N - y}'
