@@ -23,19 +23,17 @@ def env(**kwargs):
 
 class raw_env(RLCardBase):
 
-    metadata = {"render.modes": ["human"], "name": "leduc_holdem_v4"}
+    metadata = {'render.modes': ['human'], "name": "leduc_holdem_v4"}
 
     def __init__(self, num_players=2):
         super().__init__("leduc-holdem", num_players, (36,))
 
-    def render(self, mode="human"):
+    def render(self, mode='human'):
         for player in self.possible_agents:
             state = self.env.game.get_state(self._name_to_int(player))
             print(f"\n=============== {player}'s Hand ===============")
-            print_card(state["hand"])
-            print("\n{}'s Chips: {}".format(player, state["my_chips"]))
-        print("\n================= Public Cards =================")
-        print_card(state["public_card"]) if state["public_card"] is not None else print(
-            "No public cards."
-        )
-        print("\n")
+            print_card(state['hand'])
+            print("\n{}'s Chips: {}".format(player, state['my_chips']))
+        print('\n================= Public Cards =================')
+        print_card(state['public_card']) if state['public_card'] is not None else print('No public cards.')
+        print('\n')
