@@ -21,26 +21,17 @@ def env(**kwargs):
 
 class raw_env(RLCardBase):
 
-    metadata = {"render.modes": ["human"], "name": "mahjong_v4"}
+    metadata = {'render.modes': ['human'], "name": "mahjong_v4"}
 
     def __init__(self):
         super().__init__("mahjong", 4, (6, 34, 4))
 
-    def render(self, mode="human"):
+    def render(self, mode='human'):
         for player in self.possible_agents:
             state = self.env.game.get_state(self._name_to_int(player))
             print(f"\n======== {player}'s Hand ========")
-            print(", ".join([c.get_str() for c in state["current_hand"]]))
-            print(
-                f"\n{player}'s Piles: ",
-                ", ".join(
-                    [
-                        c.get_str()
-                        for pile in state["players_pile"][self._name_to_int(player)]
-                        for c in pile
-                    ]
-                ),
-            )
+            print(', '.join([c.get_str() for c in state['current_hand']]))
+            print(f"\n{player}'s Piles: ", ', '.join([c.get_str() for pile in state['players_pile'][self._name_to_int(player)] for c in pile]))
         print("\n======== Tiles on Table ========")
-        print(", ".join([c.get_str() for c in state["table"]]))
-        print("\n")
+        print(', '.join([c.get_str() for c in state['table']]))
+        print('\n')
