@@ -23,7 +23,7 @@ def env(**kwargs):
 
 class raw_env(RLCardBase):
 
-    metadata = {"render.modes": ["human"], "name": "uno_v4"}
+    metadata = {'render.modes': ['human'], 'name': 'uno_v4'}
 
     def __init__(self, opponents_hand_visible=False):
         self._opponents_hand_visible = opponents_hand_visible
@@ -33,25 +33,25 @@ class raw_env(RLCardBase):
     def observe(self, agent):
         obs = self.env.get_state(self._name_to_int(agent))
         if self._opponents_hand_visible:
-            observation = obs["obs"].astype(self._dtype)
+            observation = obs['obs'].astype(self._dtype)
         else:
-            observation = obs["obs"][0:4, :, :].astype(self._dtype)
+            observation = obs['obs'][0:4, :, :].astype(self._dtype)
 
         legal_moves = self.next_legal_moves
-        action_mask = np.zeros(61, int)
+        action_mask = np.zeros(61, 'int8')
         for i in legal_moves:
             action_mask[i] = 1
 
-        return {"observation": observation, "action_mask": action_mask}
+        return {'observation': observation, 'action_mask': action_mask}
 
-    def render(self, mode="human"):
+    def render(self, mode='human'):
         for player in self.possible_agents:
             state = self.env.game.get_state(self._name_to_int(player))
             print(f"\n\n=============== {player}'s Hand ===============")
-            UnoCard.print_cards(state["hand"])
-        print("\n\n================= Target Card =================")
-        UnoCard.print_cards(state["target"], wild_color=True)
-        print("\n")
+            UnoCard.print_cards(state['hand'])
+        print('\n\n================= Target Card =================')
+        UnoCard.print_cards(state['target'], wild_color=True)
+        print('\n')
 
     def close(self):
         pass
