@@ -1,4 +1,4 @@
-class BaseScenario(object):  # defines scenario upon which the world is built
+class BaseScenario:  # defines scenario upon which the world is built
     def make_world(self):  # create elements of the world
         raise NotImplementedError()
 
