@@ -5,6 +5,7 @@ from .._mpe_utils.scenario import BaseScenario
 
 
 class Scenario(BaseScenario):
+
     def make_world(self, N=2):
         world = World()
         # set any world properties first
@@ -19,14 +20,14 @@ class Scenario(BaseScenario):
             agent.adversary = True if i < num_adversaries else False
             base_name = "adversary" if agent.adversary else "agent"
             base_index = i if i < num_adversaries else i - num_adversaries
-            agent.name = f"{base_name}_{base_index}"
+            agent.name = f'{base_name}_{base_index}'
             agent.collide = False
             agent.silent = True
             agent.size = 0.15
         # add landmarks
         world.landmarks = [Landmark() for i in range(num_landmarks)]
         for i, landmark in enumerate(world.landmarks):
-            landmark.name = "landmark %d" % i
+            landmark.name = 'landmark %d' % i
             landmark.collide = False
             landmark.movable = False
             landmark.size = 0.08
@@ -62,9 +63,7 @@ class Scenario(BaseScenario):
             dists = []
             for l in world.landmarks:
                 dists.append(np.sum(np.square(agent.state.p_pos - l.state.p_pos)))
-            dists.append(
-                np.sum(np.square(agent.state.p_pos - agent.goal_a.state.p_pos))
-            )
+            dists.append(np.sum(np.square(agent.state.p_pos - agent.goal_a.state.p_pos)))
             return tuple(dists)
 
     # return all agents that are not adversaries
@@ -77,11 +76,7 @@ class Scenario(BaseScenario):
 
     def reward(self, agent, world):
         # Agents are rewarded based on minimum agent distance to each landmark
-        return (
-            self.adversary_reward(agent, world)
-            if agent.adversary
-            else self.agent_reward(agent, world)
-        )
+        return self.adversary_reward(agent, world) if agent.adversary else self.agent_reward(agent, world)
 
     def agent_reward(self, agent, world):
         # Rewarded based on how close any good agent is to the goal landmark, and how far the adversary is from it
@@ -91,55 +86,35 @@ class Scenario(BaseScenario):
         # Calculate negative reward for adversary
         adversary_agents = self.adversaries(world)
         if shaped_adv_reward:  # distance-based adversary reward
-            adv_rew = sum(
-                np.sqrt(np.sum(np.square(a.state.p_pos - a.goal_a.state.p_pos)))
-                for a in adversary_agents
-            )
+            adv_rew = sum(np.sqrt(np.sum(np.square(a.state.p_pos - a.goal_a.state.p_pos))) for a in adversary_agents)
         else:  # proximity-based adversary reward (binary)
             adv_rew = 0
             for a in adversary_agents:
-                if (
-                    np.sqrt(np.sum(np.square(a.state.p_pos - a.goal_a.state.p_pos)))
-                    < 2 * a.goal_a.size
-                ):
+                if np.sqrt(np.sum(np.square(a.state.p_pos - a.goal_a.state.p_pos))) < 2 * a.goal_a.size:
                     adv_rew -= 5
 
         # Calculate positive reward for agents
         good_agents = self.good_agents(world)
         if shaped_reward:  # distance-based agent reward
             pos_rew = -min(
-                np.sqrt(np.sum(np.square(a.state.p_pos - a.goal_a.state.p_pos)))
-                for a in good_agents
-            )
+                np.sqrt(np.sum(np.square(a.state.p_pos - a.goal_a.state.p_pos))) for a in good_agents)
         else:  # proximity-based agent reward (binary)
             pos_rew = 0
-            if (
-                min(
-                    np.sqrt(np.sum(np.square(a.state.p_pos - a.goal_a.state.p_pos)))
-                    for a in good_agents
-                )
-                < 2 * agent.goal_a.size
-            ):
+            if min(np.sqrt(np.sum(np.square(a.state.p_pos - a.goal_a.state.p_pos))) for a in good_agents) \
+                    < 2 * agent.goal_a.size:
                 pos_rew += 5
             pos_rew -= min(
-                np.sqrt(np.sum(np.square(a.state.p_pos - a.goal_a.state.p_pos)))
-                for a in good_agents
-            )
+                np.sqrt(np.sum(np.square(a.state.p_pos - a.goal_a.state.p_pos))) for a in good_agents)
         return pos_rew + adv_rew
 
     def adversary_reward(self, agent, world):
         # Rewarded based on proximity to the goal landmark
         shaped_reward = True
         if shaped_reward:  # distance-based reward
-            return -np.sqrt(
-                np.sum(np.square(agent.state.p_pos - agent.goal_a.state.p_pos))
-            )
+            return -np.sqrt(np.sum(np.square(agent.state.p_pos - agent.goal_a.state.p_pos)))
         else:  # proximity-based reward (binary)
             adv_rew = 0
-            if (
-                np.sqrt(np.sum(np.square(agent.state.p_pos - agent.goal_a.state.p_pos)))
-                < 2 * agent.goal_a.size
-            ):
+            if np.sqrt(np.sum(np.square(agent.state.p_pos - agent.goal_a.state.p_pos))) < 2 * agent.goal_a.size:
                 adv_rew += 5
             return adv_rew
 
@@ -160,8 +135,6 @@ class Scenario(BaseScenario):
             other_pos.append(other.state.p_pos - agent.state.p_pos)
 
         if not agent.adversary:
-            return np.concatenate(
-                [agent.goal_a.state.p_pos - agent.state.p_pos] + entity_pos + other_pos
-            )
+            return np.concatenate([agent.goal_a.state.p_pos - agent.state.p_pos] + entity_pos + other_pos)
         else:
             return np.concatenate(entity_pos + other_pos)
