@@ -6,13 +6,11 @@ from .scenarios.simple_spread import Scenario
 
 class raw_env(SimpleEnv):
     def __init__(self, N=3, local_ratio=0.5, max_cycles=25, continuous_actions=False):
-        assert (
-            0.0 <= local_ratio <= 1.0
-        ), "local_ratio is a proportion. Must be between 0 and 1."
+        assert 0. <= local_ratio <= 1., "local_ratio is a proportion. Must be between 0 and 1."
         scenario = Scenario()
         world = scenario.make_world(N)
         super().__init__(scenario, world, max_cycles, continuous_actions, local_ratio)
-        self.metadata["name"] = "simple_spread_v2"
+        self.metadata['name'] = "simple_spread_v2"
 
 
 env = make_env(raw_env)
