@@ -5,18 +5,11 @@ from .scenarios.simple_tag import Scenario
 
 
 class raw_env(SimpleEnv):
-    def __init__(
-        self,
-        num_good=1,
-        num_adversaries=3,
-        num_obstacles=2,
-        max_cycles=25,
-        continuous_actions=False,
-    ):
+    def __init__(self, num_good=1, num_adversaries=3, num_obstacles=2, max_cycles=25, continuous_actions=False):
         scenario = Scenario()
         world = scenario.make_world(num_good, num_adversaries, num_obstacles)
         super().__init__(scenario, world, max_cycles, continuous_actions)
-        self.metadata["name"] = "simple_tag_v2"
+        self.metadata['name'] = "simple_tag_v2"
 
 
 env = make_env(raw_env)
