@@ -1,7 +1,9 @@
 import glob
 import os
+from collections import defaultdict
 from os.path import join
 from subprocess import call
+from typing import Optional
 
 import numpy as np
 import pygame
@@ -10,19 +12,35 @@ from gym.utils import seeding
 
 from .utils import agent_utils, two_d_maps
 from .utils.agent_layer import AgentLayer
-from .utils.controllers import RandomPolicy, SingleActionPolicy
+from .utils.controllers import PursuitPolicy, RandomPolicy, SingleActionPolicy
 
 os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
 
 
-class Pursuit():
+class Pursuit:
 
-    def __init__(self, **kwargs):
+    def __init__(self, x_size: int = 16,
+                 y_size: int = 16,
+                 max_cycles: int = 500,
+                 shared_reward: bool = True,
+                 n_evaders: int = 30,
+                 n_pursuers: int = 8,
+                 obs_range: int = 7,
+                 n_catch: int = 2,
+                 freeze_evaders: bool = False,
+                 evader_controller: Optional[PursuitPolicy] = None,
+                 pursuer_controller: Optional[PursuitPolicy] = None,
+                 tag_reward: float = 0.01,
+                 catch_reward: float = 5.0,
+                 urgency_reward: float = -0.1,
+                 surround: bool = True,
+                 constraint_window: float = 1.0
+                 ):
         """
-        In evade purusit a set of pursuers must 'tag' a set of evaders
+        In evade pursuit a set of pursuers must 'tag' a set of evaders
         Required arguments:
             x_size, y_size: World size
-            local_ratio: proportion of reward allocated locally vs distributed among all agents
+            shared_reward: whether the rewards should be shared between all agents
             n_evaders
             n_pursuers
             obs_range: how far each agent can see
@@ -41,18 +59,17 @@ class Pursuit():
         constraint_window: window in which agents can randomly spawn
         """
 
-        self.x_size = kwargs.pop('x_size', 16)
-        self.y_size = kwargs.pop('y_size', 16)
-        x_size = self.x_size
-        y_size = self.y_size
+        self.x_size = x_size
+        self.y_size = y_size
         self.map_matrix = two_d_maps.rectangle_map(self.x_size, self.y_size)
-        self.max_cycles = kwargs.pop("max_cycles", 500)
+        self.max_cycles = max_cycles
         self.seed()
 
-        self.local_ratio = kwargs.pop('local_ratio', 1.0)
+        self.shared_reward = shared_reward
+        self.local_ratio = 1.0 - float(self.shared_reward)
 
-        self.n_evaders = kwargs.pop('n_evaders', 30)
-        self.n_pursuers = kwargs.pop('n_pursuers', 8)
+        self.n_evaders = n_evaders
+        self.n_pursuers = n_pursuers
         self.num_agents = self.n_pursuers
 
         self.latest_reward_state = [0 for _ in range(self.num_agents)]
@@ -60,7 +77,7 @@ class Pursuit():
         self.latest_obs = [None for _ in range(self.num_agents)]
 
         # can see 7 grids around them by default
-        self.obs_range = kwargs.pop('obs_range', 7)
+        self.obs_range = obs_range
         # assert self.obs_range % 2 != 0, "obs_range should be odd"
         self.obs_offset = int((self.obs_range - 1) / 2)
         self.pursuers = agent_utils.create_agents(
@@ -71,31 +88,27 @@ class Pursuit():
         self.pursuer_layer = AgentLayer(x_size, y_size, self.pursuers)
         self.evader_layer = AgentLayer(x_size, y_size, self.evaders)
 
-        self.n_catch = kwargs.pop('n_catch', 2)
+        self.n_catch = n_catch
 
         n_act_purs = self.pursuer_layer.get_nactions(0)
         n_act_ev = self.evader_layer.get_nactions(0)
 
-        self.freeze_evaders = kwargs.pop('freeze_evaders', False)
+        self.freeze_evaders = freeze_evaders
 
         if self.freeze_evaders:
-            self.evader_controller = kwargs.pop(
-                'evader_controller', SingleActionPolicy(4))
-            self.pursuer_controller = kwargs.pop(
-                'pursuer_controller', SingleActionPolicy(4))
+            self.evader_controller = SingleActionPolicy(4) if evader_controller is None else evader_controller
+            self.pursuer_controller = SingleActionPolicy(4) if pursuer_controller is None else pursuer_controller
         else:
-            self.evader_controller = kwargs.pop(
-                'evader_controller', RandomPolicy(n_act_purs, self.np_random))
-            self.pursuer_controller = kwargs.pop(
-                'pursuer_controller', RandomPolicy(n_act_ev, self.np_random))
+            self.evader_controller = RandomPolicy(n_act_purs, self.np_random) if evader_controller is None else evader_controller
+            self.pursuer_controller = RandomPolicy(n_act_ev, self.np_random) if pursuer_controller is None else pursuer_controller
 
         self.current_agent_layer = np.zeros((x_size, y_size), dtype=np.int32)
 
-        self.tag_reward = kwargs.pop('tag_reward', 0.01)
+        self.tag_reward = tag_reward
 
-        self.catch_reward = kwargs.pop('catch_reward', 5.0)
+        self.catch_reward = catch_reward
 
-        self.urgency_reward = kwargs.pop('urgency_reward', 0.0)
+        self.urgency_reward = urgency_reward
 
         self.ally_actions = np.zeros(n_act_purs, dtype=np.int32)
         self.opponent_actions = np.zeros(n_act_ev, dtype=np.int32)
@@ -111,9 +124,9 @@ class Pursuit():
 
         self.evaders_gone = np.array([False for i in range(self.n_evaders)])
 
-        self.surround = kwargs.pop('surround', True)
+        self.surround = surround
 
-        self.constraint_window = kwargs.pop('constraint_window', 1.0)
+        self.constraint_window = constraint_window
 
         self.surround_mask = np.array([[-1, 0], [1, 0], [0, 1], [0, -1]])
 
@@ -124,7 +137,6 @@ class Pursuit():
 
         self.frames = 0
         self.reset()
-        assert not kwargs, f"gave arguments {list(kwargs.keys())} that are not valid pursuit arguments"
 
     def observation_space(self, agent):
         return self.observation_spaces[agent]
@@ -199,12 +211,16 @@ class Pursuit():
         opponent_layer = self.evader_layer
         opponent_controller = self.evader_controller
 
-        # actual action application
+        # actual action application, change the pursuer layer
         agent_layer.move_agent(agent_id, action)
 
+        # Update only the pursuer layer
+        self.model_state[1] = self.pursuer_layer.get_state_matrix()
+
         self.latest_reward_state = self.reward() / self.num_agents
 
         if is_last:
+            # Possibly change the evader layer
             ev_remove, pr_remove, pursuers_who_remove = self.remove_agents()
 
             for i in range(opponent_layer.n_agents()):
@@ -214,16 +230,15 @@ class Pursuit():
 
             self.latest_reward_state += self.catch_reward * pursuers_who_remove
             self.latest_reward_state += self.urgency_reward
+            self.frames = self.frames + 1
 
+        # Update the remaining layers
         self.model_state[0] = self.map_matrix
-        self.model_state[1] = self.pursuer_layer.get_state_matrix()
         self.model_state[2] = self.evader_layer.get_state_matrix()
 
-        if is_last:
-            global_val = self.latest_reward_state.mean()
-            local_val = self.latest_reward_state
-            self.latest_reward_state = self.local_ratio * local_val + (1 - self.local_ratio) * global_val
-            self.frames = self.frames + 1
+        global_val = self.latest_reward_state.mean()
+        local_val = self.latest_reward_state
+        self.latest_reward_state = self.local_ratio * local_val + (1 - self.local_ratio) * global_val
 
     def draw_model_state(self):
         # -1 is building pixel flag
@@ -265,6 +280,54 @@ class Pursuit():
 
             pygame.draw.circle(self.screen, col, center, int(self.pixel_scale / 3))
 
+    def draw_agent_counts(self):
+        font = pygame.font.SysFont('Comic Sans MS', self.pixel_scale * 2 // 3)
+
+        agent_positions = defaultdict(int)
+        evader_positions = defaultdict(int)
+
+        for i in range(self.evader_layer.n_agents()):
+            x, y = self.evader_layer.get_position(i)
+            evader_positions[(x, y)] += 1
+
+        for i in range(self.pursuer_layer.n_agents()):
+            x, y = self.pursuer_layer.get_position(i)
+            agent_positions[(x, y)] += 1
+
+        for (x, y) in evader_positions:
+            (pos_x, pos_y) = (self.pixel_scale * x + self.pixel_scale // 2,
+                              self.pixel_scale * y + self.pixel_scale // 2)
+
+            agent_count = evader_positions[(x, y)]
+            count_text: str
+            if agent_count < 1:
+                count_text = ""
+            elif agent_count < 10:
+                count_text = str(agent_count)
+            else:
+                count_text = "+"
+
+            text = font.render(count_text, False, (0, 255, 255))
+
+            self.screen.blit(text, (pos_x, pos_y))
+
+        for (x, y) in agent_positions:
+            (pos_x, pos_y) = (self.pixel_scale * x + self.pixel_scale // 2,
+                              self.pixel_scale * y + self.pixel_scale // 2)
+
+            agent_count = agent_positions[(x, y)]
+            count_text: str
+            if agent_count < 1:
+                count_text = ""
+            elif agent_count < 10:
+                count_text = str(agent_count)
+            else:
+                count_text = "+"
+
+            text = font.render(count_text, False, (255, 255, 0))
+
+            self.screen.blit(text, (pos_x, pos_y - self.pixel_scale // 2))
+
     def render(self, mode="human"):
         if not self.renderOn:
             if mode == "human":
@@ -281,6 +344,7 @@ class Pursuit():
 
         self.draw_evaders()
         self.draw_pursuers()
+        self.draw_agent_counts()
 
         observation = pygame.surfarray.pixels3d(self.screen)
         new_observation = np.copy(observation)
@@ -289,32 +353,6 @@ class Pursuit():
             pygame.display.flip()
         return np.transpose(new_observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
 
-    def animate(self, act_fn, nsteps, file_name, rate=1.5, verbose=False):
-        """
-            Save an animation to an mp4 file.
-        """
-        # run sim loop
-        o = self.reset()
-        file_path = "/".join(file_name.split("/")[0:-1])
-        temp_name = join(file_path, "temp_0.png")
-        # generate .pngs
-        self.save_image(temp_name)
-        removed = 0
-        for i in range(nsteps):
-            a = act_fn(o)
-            o, r, done, info = self.step(a)
-            temp_name = join(file_path, "temp_" + str(i + 1) + ".png")
-            self.save_image(temp_name)
-            removed += info['removed']
-            if done:
-                break
-        # use ffmpeg to create .pngs to .mp4 movie
-        ffmpeg_cmd = "ffmpeg -framerate " + str(rate) + " -i " + join(
-            file_path, "temp_%d.png") + " -c:v libx264 -pix_fmt yuv420p " + file_name
-        call(ffmpeg_cmd.split())
-        # clean-up by removing .pngs
-        map(os.remove, glob.glob(join(file_path, "temp_*.png")))
-
     def save_image(self, file_name):
         self.render()
         capture = pygame.surfarray.array3d(self.screen)
@@ -410,7 +448,7 @@ class Pursuit():
             x, y = self.evader_layer.get_position(ai)
             if self.surround:
                 pos_that_catch = self.surround_mask + \
-                    self.evader_layer.get_position(ai)
+                                 self.evader_layer.get_position(ai)
                 truths = np.array(
                     [np.equal([xi, yi], pos_that_catch).all(axis=1) for xi, yi in zip(xpur, ypur)])
                 if np.sum(truths.any(axis=0)) == self.need_to_surround(x, y):
