@@ -124,7 +124,7 @@ class MAWaterWorld():
                  radius=0.015, obstacle_radius=0.2, obstacle_coord=np.array([0.5, 0.5]),
                  pursuer_max_accel=0.01, evader_speed=0.01, poison_speed=0.01, poison_reward=-1.0,
                  food_reward=10.0, encounter_reward=0.01, thrust_penalty=-0.5, local_ratio=1.0,
-                 speed_features=True, max_cycles=500, **kwargs):
+                 speed_features=True, max_cycles=500):
         """
         n_pursuers: number of pursuing archea (agents)
         n_evaders: number of evader archea
