@@ -30,7 +30,7 @@ def average_total_reward(env, max_episodes=100, max_steps=10000000000):
             elif isinstance(obs, dict) and 'action_mask' in obs:
                 action = random.choice(np.flatnonzero(obs['action_mask']))
             else:
-                action = env.action_spaces[agent].sample()
+                action = env.action_space(agent).sample()
             env.step(action)
 
         num_episodes = episode + 1
