@@ -36,13 +36,6 @@ class to_parallel_wrapper(ParallelEnv):
     def __init__(self, aec_env):
         self.aec_env = aec_env
 
-        # try to access these parameters for backwards compatability
-        try:
-            self._observation_spaces = self.aec_env.observation_spaces
-            self._action_spaces = self.aec_env.action_spaces
-        except AttributeError:
-            pass
-
         try:
             self.possible_agents = aec_env.possible_agents
         except AttributeError:
@@ -60,7 +53,7 @@ class to_parallel_wrapper(ParallelEnv):
     def observation_spaces(self):
         warnings.warn("The `observation_spaces` dictionary is deprecated. Use the `observation_space` function instead.")
         try:
-            return self._observation_spaces
+            return {agent: self.observation_space(agent) for agent in self.possible_agents}
         except AttributeError:
             raise AttributeError("The base environment does not have an `observation_spaces` dict attribute. Use the environments `observation_space` method instead")
 
@@ -68,7 +61,7 @@ class to_parallel_wrapper(ParallelEnv):
     def action_spaces(self):
         warnings.warn("The `action_spaces` dictionary is deprecated. Use the `action_space` function instead.")
         try:
-            return self._action_spaces
+            return {agent: self.action_space(agent) for agent in self.possible_agents}
         except AttributeError:
             raise AttributeError("The base environment does not have an action_spaces dict attribute. Use the environments `action_space` method instead")
 
@@ -136,12 +129,6 @@ class from_parallel_wrapper(AECEnv):
         except AttributeError:
             pass
 
-        # try to access these parameters for backwards compatability
-        try:
-            self._observation_spaces = self.env.observation_spaces
-            self._action_spaces = self.env.action_spaces
-        except AttributeError:
-            pass
         # Not every environment has the .state_space attribute implemented
         try:
             self.state_space = self.env.state_space
@@ -156,7 +143,7 @@ class from_parallel_wrapper(AECEnv):
     def observation_spaces(self):
         warnings.warn("The `observation_spaces` dictionary is deprecated. Use the `observation_space` function instead.")
         try:
-            return self._observation_spaces
+            return {agent: self.observation_space(agent) for agent in self.possible_agents}
         except AttributeError:
             raise AttributeError("The base environment does not have an `observation_spaces` dict attribute. Use the environments `observation_space` method instead")
 
@@ -164,7 +151,7 @@ class from_parallel_wrapper(AECEnv):
     def action_spaces(self):
         warnings.warn("The `action_spaces` dictionary is deprecated. Use the `action_space` function instead.")
         try:
-            return self._action_spaces
+            return {agent: self.action_space(agent) for agent in self.possible_agents}
         except AttributeError:
             raise AttributeError("The base environment does not have an action_spaces dict attribute. Use the environments `action_space` method instead")
 
