@@ -25,7 +25,7 @@ def random_demo(env, render=True, episodes=1):
             elif isinstance(obs, dict) and 'action_mask' in obs:
                 action = random.choice(np.flatnonzero(obs['action_mask']))
             else:
-                action = env.action_spaces[agent].sample()
+                action = env.action_space(agent).sample()
             env.step(action)
 
         completed_episodes += 1
